@@ -298,7 +298,6 @@
         <translation>Выбор шрифта</translation>
     </message>
 </context>
-
 <context>
     <name>Details</name>
     <message>
@@ -311,12 +310,12 @@
     <name>MainWindow</name>
     <message>
         <location filename="../../ui/mainwindow.ui" line="+148"/>
-        <location line="+453"/>
+        <location line="+447"/>
         <source>Find</source>
         <translation>Поиск</translation>
     </message>
     <message>
-        <location line="-360"/>
+        <location line="-354"/>
         <source>Waiting time</source>
         <translation>Время ожидания</translation>
     </message>
@@ -356,7 +355,12 @@
         <translation>&amp;Инфо</translation>
     </message>
     <message>
-        <location line="+104"/>
+        <location line="+8"/>
+        <source>&amp;Help</source>
+        <translation>&amp;Справка</translation>
+    </message>
+    <message>
+        <location line="+90"/>
         <source>Ctrl+F</source>
         <translation></translation>
     </message>
@@ -468,17 +472,17 @@
         <translation>Транслитерация</translation>
     </message>
     <message>
-        <location line="-358"/>
+        <location line="-352"/>
         <source>Routes</source>
         <translation>Маршруты</translation>
     </message>
     <message>
-        <location line="+338"/>
+        <location line="+332"/>
         <source>About...</source>
         <translation>О программе...</translation>
     </message>
     <message>
-        <location filename="../../src/mainwindow.cpp" line="+372"/>
+        <location filename="../../src/mainwindow.cpp" line="+439"/>
         <source>Open file</source>
         <translation>Открыть файл</translation>
     </message>
@@ -489,65 +493,81 @@
     </message>
     <message>
         <source>Save file</source>
-        <translation type="obsolete">Сохранить файл</translation>
+        <translation>Сохранить файл</translation>
     </message>
     <message>
         <source>Unknown author</source>
-        <translation type="obsolete">Неизвестный автор</translation>
+        <translation>Неизвестный автор</translation>
     </message>
     <message>
         <source>About</source>
-        <translation type="obsolete">О программе</translation>
+        <translation>О программе</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation type="obsolete">Помощь</translation>
+        <translation>Помощь</translation>
     </message>
     <message>
         <source>transit system map</source>
-        <translation type="obsolete">карта транспортной системы</translation>
+        <translation>карта транспортной системы</translation>
     </message>
     <message>
         <source>Version</source>
-        <translation type="obsolete">Версия</translation>
+        <translation>Версия</translation>
     </message>
     <message>
         <source>Data files by</source>
-        <translation type="obsolete">Файлы данных предоставил</translation>
+        <translation>Файлы данных предоставил</translation>
     </message>
     <message>
         <source>Author of map file format</source>
-        <translation type="obsolete">Автор формата файла карт</translation>
+        <translation>Автор формата файла карт</translation>
     </message>
     <message>
         <source>About current map file</source>
-        <translation type="obsolete">О текущем файле карты</translation>
+        <translation>О текущем файле карты</translation>
     </message>
     <message>
         <source>Author of translation: Gusak Leonid</source>
-        <translation type="obsolete">Автор перевода: Гусак Леонид</translation>
+        <translation>Автор перевода: Гусак Леонид</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation type="obsolete">ОК</translation>
+        <translation>ОК</translation>
     </message>
     <message>
-        <location line="+207"/>
+        <location line="+210"/>
         <source>All</source>
         <translation>Все</translation>
     </message>
     <message>
-        <location line="+0"/>
+        <location line="-406"/>
+        <location line="+406"/>
         <source>Information</source>
         <translation>Информация</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="-404"/>
+        <source>Start</source>
+        <translation>Начальная</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Finish</source>
+        <translation>Конечная</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Default start</source>
+        <translation>Начальная по умолчанию</translation>
+    </message>
+    <message>
+        <location line="+407"/>
         <source>Categories</source>
         <translation>Категории</translation>
     </message>
     <message>
-        <location line="+226"/>
+        <location line="+228"/>
         <source>Add maps</source>
         <translation>Добавление карты</translation>
     </message>
@@ -562,15 +582,15 @@
     </message>
     <message>
         <source>Author of this map file</source>
-        <translation type="obsolete">Автор этого файла карты</translation>
+        <translation>Автор этого файла карты</translation>
     </message>
     <message>
         <source>This program uses</source>
-        <translation type="obsolete">Эта программа использует</translation>
+        <translation>Эта программа использует</translation>
     </message>
     <message>
         <source>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.</source>
-        <translation type="obsolete">Эта программа распространяется в надежде, что она будет полезной, но БЕЗ ВСЯКИХ ГАРАНТИЙ, в том числе подразумеваемых гарантий ТОВАРНОГО СОСТОЯНИЯ ПРИ ПРОДАЖЕ и ГОДНОСТИ ДЛЯ ОПРЕДЕЛЁННОГО ПРИМЕНЕНИЯ. Смотрите Стандартную Общественную Лицензию GNU для получения дополнительной информации.</translation>
+        <translation>Эта программа распространяется в надежде, что она будет полезной, но БЕЗ ВСЯКИХ ГАРАНТИЙ, в том числе подразумеваемых гарантий ТОВАРНОГО СОСТОЯНИЯ ПРИ ПРОДАЖЕ и ГОДНОСТИ ДЛЯ ОПРЕДЕЛЁННОГО ПРИМЕНЕНИЯ. Смотрите Стандартную Общественную Лицензию GNU для получения дополнительной информации.</translation>
     </message>
 </context>
 <context>
@@ -627,10 +647,10 @@
     </message>
     <message>
         <source>Background</source>
-        <translation type="obsolete">Фон</translation>
+        <translation>Фон</translation>
     </message>
     <message>
-        <location filename="../../src/settings.cpp" line="+46"/>
+        <location filename="../../src/settings.cpp" line="+45"/>
         <source>Color...</source>
         <translation>Цвет...</translation>
     </message>
@@ -666,7 +686,7 @@
     </message>
     <message>
         <source>Full screen mode</source>
-        <translation type="obsolete">Полноэкранный режим</translation>
+        <translation>Полноэкранный режим</translation>
     </message>
     <message>
         <location line="+53"/>
@@ -695,7 +715,7 @@
     </message>
     <message>
         <source>Simple graphics for transfers</source>
-        <translation type="obsolete">Упрощённая графика для переходов</translation>
+        <translation>Упрощённая графика для переходов</translation>
     </message>
     <message>
         <location line="+52"/>
@@ -721,22 +741,19 @@
 <context>
     <name>TMapView</name>
     <message>
-        <location filename="../../src/mapview/mapview.cpp" line="+102"/>
         <source>Information</source>
         <translation>Информация</translation>
     </message>
     <message>
-        <location line="+4"/>
         <source>Start</source>
         <translation>Начальная</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>Finish</source>
         <translation>Конечная</translation>
     </message>
     <message>
-        <location line="+225"/>
+        <location filename="../../src/mapview/mapview.cpp" line="+357"/>
         <source>Day</source>
         <translation>День</translation>
     </message>
@@ -763,7 +780,7 @@
 %1</translation>
     </message>
     <message>
-        <location line="+1058"/>
+        <location line="+1093"/>
         <source>line</source>
         <translation>линия</translation>
     </message>
@@ -783,24 +800,24 @@
         <translation>Переход на станцию:</translation>
     </message>
     <message>
-        <location line="+254"/>
+        <location line="+262"/>
         <source>Save file</source>
         <translation>Сохранить файл</translation>
     </message>
     <message>
         <source>All</source>
-        <translation type="obsolete">Все</translation>
+        <translation>Все</translation>
     </message>
     <message>
         <source>Categories</source>
-        <translation type="obsolete">Категории</translation>
+        <translation>Категории</translation>
     </message>
     <message>
         <source>Transfer at station:</source>
-        <translation type="obsolete">Переход на станцию:</translation>
+        <translation>Переход на станцию:</translation>
     </message>
     <message>
-        <location line="-249"/>
+        <location line="-257"/>
         <source>Final station:</source>
         <translation>Конечная станция:</translation>
     </message>
@@ -917,7 +934,6 @@
 <context>
     <name>TMobileUi</name>
     <message>
-        <location filename="../../src/mobileui.cpp" line="+43"/>
         <source>Help</source>
         <translation>Помощь</translation>
     </message>
@@ -925,12 +941,12 @@
 <context>
     <name>About</name>
     <message>
-        <location filename="../../src/about.h" line="+26"/>
+        <location filename="../../src/about.h" line="+27"/>
         <source>About</source>
         <translation>О программе</translation>
     </message>
     <message>
-        <location line="+35"/>
+        <location line="+36"/>
         <source>Unknown author</source>
         <translation>Неизвестный автор</translation>
     </message>
