@@ -97,7 +97,6 @@ void TCompleter::showCompletion(QList< QPair<QString,QColor> > list)
 
  popup->setUpdatesEnabled(false);
  popup->clear();
- int FontSize=QFont().pointSize()*2;
  for (int i = 0; i < list.count(); ++i)
  {
   QTreeWidgetItem * item;
@@ -105,7 +104,7 @@ void TCompleter::showCompletion(QList< QPair<QString,QColor> > list)
   item->setText(0, list.at(i).first);
 #ifdef Q_WS_MAEMO_5
   item->setText(1,"=");
-  item->setFont(1,QFont("",FontSize,87));
+  item->setFont(1,QFont("",QFont().pointSize()*2,87));
   item->setTextColor(1, list.at(i).second);
 #endif
   item->setBackgroundColor(1,list.at(i).second);
@@ -125,6 +124,7 @@ void TCompleter::showCompletion(QList< QPair<QString,QColor> > list)
  popup->move(editor->mapToGlobal(QPoint(0, editor->height())));
  popup->setFocus();
  popup->show();
+ popup->repaint();
 }
 
 void TCompleter::doneCompletion()
@@ -136,15 +136,16 @@ void TCompleter::doneCompletion()
  if (item)
  {
   int i=idFiltred.at(popup->currentIndex().row());
-  emit doneCompletionByID(i);
   editor->setText(item->text(0));
   QMetaObject::invokeMethod(editor, "returnPressed");
+  emit doneCompletionByID(i);
  }
 }
 
 void TCompleter::autoSuggest()
 {
  showCompletion(filterList(list,editor->text()));
+ emit doneSuggestByID(idFiltred);
 }
 
 void TCompleter::preventSuggest()
@@ -166,7 +167,6 @@ TCompleter::filterList(QList< QPair<QString,QColor> > list, QString filter)
    filtred << list.at(i);
    idFiltred << i;
   }
- emit doneSuggestByID(idFiltred);
  return filtred;
 }
 
