@@ -10,12 +10,14 @@ class QTimer;
 class QTreeWidget;
 QT_END_NAMESPACE
 
+class TMapView;
+
 class TCompleter : public QObject
 {
     Q_OBJECT
 
 public:
-    TCompleter(QList< QPair<QString,QColor> > data,QLineEdit *parent = 0);
+    TCompleter(TMapView *map,QLineEdit *parent = 0);
     ~TCompleter();
     bool eventFilter(QObject *obj, QEvent *ev);
     void showCompletion(QList< QPair<QString,QColor> > list);
