@@ -7,19 +7,27 @@ Details::Details(QWidget *parent) :
     ui(new Ui::Details)
 {
  setWindowFlags(windowFlags() & (~Qt::WindowContextHelpButtonHint));
+ installEventFilter(this);
  ui->setupUi(this);
 }
 
 Details::~Details()
 {
-    delete ui;
+ delete ui;
 }
 
 void Details::closeEvent(QCloseEvent *e)
 {Q_UNUSED(e);
+ removeEventFilter(this);
  delete this;
 }
 
+bool Details::eventFilter(QObject *obj, QEvent *e)
+{Q_UNUSED(obj);
+ QDialog::event(e);
+ if(e->type()==QEvent::Resize) emit resizeWindow();
+ return 1;
+}
 
 void Details::keyPressEvent(QKeyEvent *e)
 {
