@@ -17,11 +17,15 @@ public:
 
     Ui::Details *ui;
 
+signals:
+    void resizeWindow();
+
 private:
     void closeEvent(QCloseEvent *e);
 
 protected:
     void keyPressEvent(QKeyEvent *e);
+    bool eventFilter(QObject *obj, QEvent *event);
 
 };
 
