@@ -211,8 +211,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
  }else
  {
-  setFixedWidth(qApp->desktop()->width());
-  setFixedHeight(qApp->desktop()->height());
+  resize(qApp->desktop()->width(),qApp->desktop()->height());
   centralWidget()->layout()->addWidget(map);
   mUi = new TMobileUi(this,map);
   //setCentralWidget(map);
@@ -242,8 +241,8 @@ MainWindow::MainWindow(QWidget *parent) :
       ui->mFullScreen->setChecked(1);
  else (MobileVersion ? showMaximized():show());
 
- //map->resize(qApp->desktop()->width(),qApp->desktop()->availableGeometry().height()-(height()-map->height())-20);
- map->resize(geometry().right()-geometry().left(),geometry().bottom()-geometry().top()-(height()-map->height()));
+ if(windowState()==Qt::WindowMaximized) // Under linux that need for correct FitInView
+  map->resize(qApp->desktop()->availableGeometry().width(),qApp->desktop()->availableGeometry().height()-(height()-map->height())-20);
  loadSettings();
 
  if(Config.mapZoomFactorCheck) // first
@@ -357,17 +356,6 @@ void MainWindow::checkNodeDefault()
  map->nodePopup->actions().at(5)->setChecked((map->nodeClick->ID==Config.mapDefaultStationID));
 }
 
-//bool MainWindow::eventFilter(QObject *obj, QEvent *ev)
-//{
-// if(obj==ui->eSearch && ui->eSearch->isVisible() && ev->type()==QEvent::FocusIn)
-// {
-//  ui->eSearch->selectAll();
-//  return 1;
-// }else
-//  return MainWindow::eventFilter(obj,ev);
-//}
-
-//bool MainWindow::event(QEvent *e)
 bool MainWindow::eventFilter(QObject *obj, QEvent *e)
 {
 
@@ -628,7 +616,7 @@ void MainWindow::nodeInformation()
 
 
  DetailsWindow->setWindowTitle((MobileVersion ? "":DetailsWindow->windowTitle()+" ")+map->nodeClick->DisplayName);
-
+ DetailsWindow->resize(640,480);
  map->loadNodeInfo(map->nodeClick);
 
  TMapView *MapScheme;
@@ -670,8 +658,11 @@ void MainWindow::nodeInformation()
     MapScheme->horizontalScrollBar()->setValue(MapScheme->horizontalScrollBar()->maximum()/2);
     MapScheme->verticalScrollBar()->setValue(MapScheme->verticalScrollBar()->maximum()/2);
     MapScheme->state.mapLoaded=1;
+
     Tabs->addTab(MapScheme,key);
     new TMobileUi(this,MapScheme,1);
+    if(!MobileVersion)
+     connect(DetailsWindow,SIGNAL(resizeWindow()),MapScheme,SLOT(fitMap()));
    }
   }else
    AllText+=QString("<h3>%1</h3><br>%2<br>").arg(key).arg(Info.Value);
@@ -696,6 +687,7 @@ void MainWindow::nodeInformation()
    else continue;
   }
  }
+
  if(Tabs->count()) DetailsWindow->showMaximized();
 
 //qDebug() << testTimer.elapsed();
