@@ -50,7 +50,7 @@ void TMapNode::init()
  if(!Map->config.MobileVersion) setToolTip(DisplayName);
 
  if(Rect!=QRect()) NRect=QRect(Rect.topLeft()-pos().toPoint()-QPoint(1,0),QSize(Rect.width(),Rect.height()));
- else NRect=Rect;
+ else NRect=QRect(pos().toPoint(),QSize(1,1));
  EllipseRect=QRect(QPoint(-sWidth,-sWidth),QPoint(sWidth,sWidth));
  Align=Map->params.nodeFontStyle;
  Vertical=0;
