@@ -91,7 +91,7 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
 
  scene = new QGraphicsScene(this);
  //scene->setItemIndexMethod - setup later at load
- //setOptimizationFlag(QGraphicsView::DontAdjustForAntialiasing);
+ setOptimizationFlag(QGraphicsView::DontAdjustForAntialiasing);
  setOptimizationFlag(QGraphicsView::DontSavePainterState);
  scene->setSceneRect(0, 0, width(), height());
  setScene(scene);
@@ -102,7 +102,7 @@ TMapView::TMapView(QString AppPath, QString CachePath) :
  //setViewportUpdateMode(QGraphicsView::MinimalViewportUpdate);
  //setViewportUpdateMode(BoundingRectViewportUpdate);
  //setViewportUpdateMode(FullViewportUpdate);
- if(config.MobileVersion) setInteractive(0);
+ //if(config.MobileVersion) setInteractive(0);
  setDragMode(QGraphicsView::ScrollHandDrag);
  setTransformationAnchor(AnchorUnderMouse);
  setResizeAnchor(AnchorViewCenter);
@@ -693,7 +693,7 @@ void TMapView::addPaintCmd(const QString &eParam,DrawType eType,QList<TPaintCmd>
     if(eType==dtRailway)
     {
      QPointF p1=cmd.polygon.at(0),p2=cmd.polygon.at(1);
-     int sign,Offset=cmd.nums.at(0)/2;
+     int Offset=cmd.nums.at(0)/2;
      if(p1.y()>p2.y()) // WARNING: ANYKEY-METHOD! ;)
      {
       if(p1.x()>p2.x()) cmd.polygon.translate(-Offset,Offset);
