@@ -93,7 +93,7 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
   connect(ui->mFind,SIGNAL(toggled(bool)),map->scene,SLOT(update()));
 
  }
- if(type) // Details
+ if(type) // Details window
  {
   lTop->addWidget(bZoomOut);
   lTop->addStretch();
@@ -104,7 +104,7 @@ TMobileUi::TMobileUi(QWidget *parent,TMapView *map,int type) : MapView(map)
   lLeft->addStretch();
 
   lBottom->addWidget(bFit);
-  lBottom->addStretch();;
+  lBottom->addStretch();
  }
 
  lToolbar->setMargin(2);
