@@ -16,14 +16,18 @@ extern IniSettingMap AppConfig;
 extern QString appPath,appConfigFile,cachePath;
 
 Settings::Settings(QWidget *parent) :
-    QDialog(parent), SBackColor(Qt::white),SShadowColor(Qt::white), MBackColor(Qt::white),
-    ui(new Ui::Settings)
+    QDialog(parent),
+    ui(new Ui::Settings),SBackColor(Qt::white),SShadowColor(Qt::white),MBackColor(Qt::white)
 {
  bool MobileVersion=mainWnd->MobileVersion;
  setWindowFlags(windowFlags() & (~Qt::WindowContextHelpButtonHint));
 
  ui->setupUi(this);
-
+ QFontMetrics fmWidth(font());
+ int WindowWidth=fmWidth.width(ui->checkMFastScrolling->text())+50;
+ setMinimumWidth(WindowWidth);
+ setMaximumWidth(WindowWidth+50);
+ resize(WindowWidth,WindowWidth*1.4);
 #ifndef Q_WS_MAEMO_5
  QObjectList l = ui->toolBox->children();
  for (QObjectList::iterator it = l.begin(); it < l.end(); it++)
@@ -39,7 +43,6 @@ Settings::Settings(QWidget *parent) :
  QString ToolStyle="QToolBox{icon-size:%1px;}"+ui->toolBox->styleSheet();
  ui->toolBox->setStyleSheet(ToolStyle.arg(fm.height()+1));
  ui->toolBox->setCurrentIndex(0);
- ui->buttonBox->addButton(QDialogButtonBox::Cancel); //setStandardButtons(QDialogButtonBox::Save|QDialogButtonBox::Close);
  ui->gbFontStation->setVisible(0);
  ui->gbFontStation->setAttribute(Qt::WA_NoSystemBackground);;
  updateLabelCacheSize();
@@ -80,7 +83,7 @@ Settings::Settings(QWidget *parent) :
 }
 
 void Settings::closeEvent(QCloseEvent * e)
-{
+{Q_UNUSED(e);
  applySettings(AppConfig);
  ((MainWindow*)parent())->SettingWindow=NULL;
  delete this;
